[glade] Let glade_property_write() save properties to <template> tags



commit 1cb4c775de111e9a297e63127597141dd0f6aab7
Author: Juan Pablo Ugarte <juanpablougarte gmail com>
Date:   Wed Jul 18 16:04:33 2012 -0300

    Let glade_property_write() save properties to <template> tags

 gladeui/glade-property.c |    5 +++--
 1 files changed, 3 insertions(+), 2 deletions(-)
---
diff --git a/gladeui/glade-property.c b/gladeui/glade-property.c
index 08eb6de..ccdf95f 100644
--- a/gladeui/glade-property.c
+++ b/gladeui/glade-property.c
@@ -1168,9 +1168,10 @@ glade_property_write (GladeProperty * property,
   g_return_if_fail (GLADE_IS_PROPERTY (property));
   g_return_if_fail (node != NULL);
 
   /* This code should work the same for <packing> and <widget> */
   if (!(glade_xml_node_verify_silent (node, GLADE_XML_TAG_PACKING) ||
-        glade_xml_node_verify_silent (node, GLADE_XML_TAG_WIDGET)))
+        glade_xml_node_verify_silent (node, GLADE_XML_TAG_WIDGET) ||
+        glade_xml_node_verify_silent (node, GLADE_XML_TAG_TEMPLATE)))
     return;
 
   /* Skip properties that are default by original pspec default
@@ -1168,9 +1168,10 @@ glade_property_write (GladeProperty * property,
   g_return_if_fail (node != NULL);
 
-  /* This code should work the same for <packing> and <widget> */
+  /* This code should work the same for <packing>, <widget> and <template> */
   if (!(glade_xml_node_verify_silent (node, GLADE_XML_TAG_PACKING) ||



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]